"""Constants for the frontend widget"""

# Symbol for joining coordinates.
# Earlier, a hyphen (-) was used. But that caused problems when
# dict keys had hyphen in them. So, we're switching to a less
# commonly used symbol.
JOIN_SYMBOL = '§'
